@@ -4,10 +4,10 @@ from .apollo_config import init_apollo_config, appllo_config
 __inited = False
 
 
-def init_config(search_path=None, hot_load=False):
+def init_config(search_path=None, hot_load=False, setting_file_name=None):
     global __inited
     __inited = True
-    init_local_config(search_path)
+    init_local_config(search_path, setting_file_name)
     app_id = local_config('apollo', 'app.id')
     if not app_id:
         return
