@@ -30,6 +30,7 @@ class RabbitmqClient(object):
         self._exchange_type = exchange_type
         self._routing_key = routing_key
         self._connected = False
+        self._check_times = 0
 
     def _connect(self):
         if not self._connected:
@@ -179,11 +180,15 @@ class RabbitmqClient(object):
                 self._channel.basic_qos(prefetch_count=1)
                 mframe, hframe, body = self._channel.basic_get(queue=self._queue, auto_ack=auto_ack)
                 if body is not None:
+                    self._check_times = 0
                     callback(body)
                     if not auto_ack:
                         self._channel.basic_ack(delivery_tag=mframe.delivery_tag)
                 else:
-                    log_info("not get new queue message for {0}".format(self._queue))
+                    self._check_times += 1
+                    if self._check_times == 10:
+                        log_info("not get new queue message for {0}".format(self._queue))
+                        self._check_times = 0
                     sleep(1)
             except Exception as e:
                 log_error('consume {} msg error({})'.format(self._queue, e))
