@@ -27,7 +27,7 @@ def get_current_second():
 
 
 def timestamp_to_str(timestamp=None, format='%Y-%m-%d %H:%M:%S'):
-    if timestamp:
+    if timestamp is not None:
         if len(str(timestamp)) > 10:
             timestamp = timestamp / (10 ** (len(str(timestamp))-10))
         time_tuple = time.localtime(timestamp)
